
no comment


/* good syntax */
body {
    width: 200px;
}


/* bad syntax */

div.bad_width {
    width: 100;
}

div.missing_coma {
    width: 100px
    height: 100px;
    display: block;
}

div.bad_value {
    font-size: inline-block;
    height: 42px;
    display: inline-block;
}

no comment
